@@ -27,7 +27,7 @@
 #include <QHash>
 #include <QStringList>
 
-#include "libkitenexport.h"
+#include "kiten_export.h"
 
 #include "dictquery.h"
 
@@ -57,7 +57,7 @@ class KITEN_EXPORT Entry
      */
     Entry( const Entry& );
     /**
-     * Constructor that includes the dictionary source. This does not need to be overridded by
+     * Constructor that includes the dictionary source. This does not need to be overridden by
      * subclasses, but you might find it to be convenient as the superclass constructor to call
      * from your constructors.
      * @param sourceDictionary the dictionary name (not fileName) that this entry originated with
@@ -162,18 +162,18 @@ class KITEN_EXPORT Entry
     virtual QString dumpEntry() const = 0;
 
     /**
-     * An overrideable sorting function, similer to operator< in most contexts
+     * An overrideable sorting function, similar to operator< in most contexts
      * The default version will sort by dictionary, then by fields
      *
      * @param that the second item we are comparing (this) with
-     * @param dictionaryList the list of dictionaries (in order) to sort
+     * @param dictOrder the list of dictionaries (in order) to sort
      *			     If this list is empty, the entries will not be sorted in order
-     * @param fieldList the list of fields to sort in, uses special codes of
+     * @param fields the list of fields to sort in, uses special codes of
      *		        Reading, Meaning, Word/Kanji for those elements, all others by their
      *		        extended attribute keys.
      */
-    virtual bool sort( const Entry &that, const QStringList &dictionaryList,
-                       const QStringList &fieldList ) const;
+    virtual bool sort( const Entry &that, const QStringList &dictOrder,
+                       const QStringList &fields ) const;
     /**
      * Overrideable sorting mechanism for sorting by individual fields.
      * The sort routine checks if the given field is equal, before calling this virtual function
